/**
 *  jQuery Font Awesome UI - Icon Browser.
 *
 * A versatile icon picker leveraging Font Awesome icons and jQuery,
 * specifically designed for the Drupal Font Awesome UI module.
 *
 * This plugin has been comprehensively rewritten and optimized
 * to fully support the Font Awesome 6 library, ensuring a seamless
 * and efficient user experience.
 *
 *  https://www.drupal.org/project/fontawesome_ui
 *
 *  Made by Mahyar Sabeti:
 *
 * {@link https://www.drupal.org/u/mahyarsbt}
 *
 *  Licensed under MIT License.
 */
(function ($) {
  $.fn.fontAwesomeIconBrowser = function (options) {
    const defaults = {
      source: {},
      messages: {
        icon_browser: 'Icon Browser',
        close_label: 'Close',
        search_placeholder: 'Search ...',
        insert_label: 'Insert'
      },
      idSuffix: '',
      allowEmpty: false,
      autoLoad: false,
      selectedIcon: '',
      clickInsert: false,
      showCount: true,
      itemsPerPage: 36,
      versionType: 'free'
    };

    const settings = $.extend(true, {}, defaults, options);
    const browser = new FontAwesomeIconBrowser(settings);

    if (settings.autoLoad) {
      $(document).ready(function () {
        browser.openModal();
      });
    }

    return this.each(function () {
      const $input = $(this);
      $input.css({
        visibility: 'hidden',
        position: 'relative',
        zIndex: '-1',
        display: 'inline-block',
        height: '40px',
        width: '102px',
        padding: '0px',
        margin: '0px -102px 0px 0px',
        border: '0px none',
        verticalAlign: 'top',
        float: 'none'
      });

      const $iconSelector = $(`
        <div class="icons-selector faui-darkgrey" style="position: relative;" data-faui-origin="${$input.attr('id')}">
          <div class="selector" data-faui-origin="${$input.attr('id')}">
            <span class="selected-icon"><i class="${settings.selectedIcon}"></i></span>
            <span class="selector-button">
              <i class="faui-icon-down-dir"></i>
            </span>
          </div>
        </div>
      `);

      $input.before($iconSelector);

      $iconSelector.find('.selector').click(function () {
        browser.openModal();
      });

      browser.$input = $input;
      browser.$iconSelector = $iconSelector;
    });
  };

  class FontAwesomeIconBrowser {
    constructor(settings) {
      this.settings = settings;
      this.currentPage = 1;
      this.iconsPerPage = settings.itemsPerPage;
      this.totalPages = 1;
      this.source = settings.source;
      this.allowEmpty = settings.allowEmpty;
      this.modalElement = null;
      this.sidebarTabs = null;
      this.sidebarTabsGroupStyle = null;
      this.sidebarTabsGroupCategories = null;
      this.iconContainer = null;
      this.footerElement = null;
      this.searchInput = null;
      this.searchQuery = '';
      this.activeCategory = 'all_categories';
      this.activeStyle = 'all';
      this.activeFamily = 'all';
      this.activeType = 'all';
      this.hasProIcons = this.checkForProIcons();
      this.hasSharpIcons = this.checkForSharpIcons();
      this.versionType = settings.versionType;
      this.init();
    }

    init() {
      this.createModal();
      this.attachEventListeners();
      this.renderSidebarTabs();
      this.renderIcons();
      this.toggleElementsVisibility();
    }

    createModal() {
      this.modalElement = $(`
        <div class="faui-modal" id="faui-modal${this.settings.idSuffix}" style="display: none;">
          <div class="faui-modal--content">
            <header class="faui-modal--header">
              <div class="faui-modal--header-logo-area">
                <i class="fa-regular fa-folder-open"></i>
                <span class="faui-modal--header-logo-title">${this.settings.messages.icon_browser}</span>
              </div>
              <div class="faui-modal--header-close-btn">
                <i class="fa-solid fa-xmark"></i>
              </div>
            </header>
            <div class="faui-modal--body claro-details__wrapper--accordion-item">
              <div class="faui-modal--sidebar">
                <div class="faui-modal--sidebar-tabs"></div>
              </div>
              <div class="faui-modal--icon-preview-wrap list-scrollbar scrollbar-2x">
                <header class="search-sticky">
                  <div class="faui-icon-families">
                    <div class="icons-facets-group-families">
                      <button class="icons-facet-tab" data-family="classic">
                        <i class="fa-solid fa-icons fa-fw fa-2x"></i>
                        <span>Classic</span>
                      </button>
                      <button class="icons-facet-tab" data-family="sharp">
                        <i class="fa-sharp fa-solid fa-icons fa-fw fa-2x"></i>
                        <span>Sharp</span>
                      </button>
                      <button class="icons-facet-tab" data-family="brands">
                        <i class="fa-brands fa-font-awesome-flag fa-fw fa-2x"></i>
                        <span>Brands</span>
                      </button>
                    </div>
                    <div class="ais-ToggleRefinement">
                      <button class="icons-facet-tab" data-type="free">
                        <i class="fa fa-bolt fa-fw fa-2x"></i>
                        <span>Free</span>
                      </button>
                    </div>
                  </div>
                  <div class="layout-container search-sticky__items">
                    <div class="search-sticky__items__inner faui-modal--icon-search">
                      <i class="fa-solid fa-magnifying-glass fa-flip-horizontal fa-2x fa-fw"></i>
                      <input name="" value="" placeholder="${this.settings.messages.search_placeholder}">
                    </div>
                  </div>
                </header>

                <div class="faui-modal--icon-preview-inner">
                <div class="search-sticky-shadow search-sticky--border"></div>
                  <div class="faui-stats">
                    <div class="icons-results-summary display-flex flex-row flex-wrap">
                      <div class="icons-results-summary-count">
                        <h1 class="h4 text-nowrap">0 Icons</h1>
                      </div>
                      <div class="icons-results-summary-pages">
                        <p class="page-info muted text-nowrap">
                          <span class="sr-only">Currently on&nbsp;</span>
                          <span class="text-capitalize">page</span>
                          <span class="current-page">1</span> of <span class="total-pages">1</span>
                        </p>
                      </div>
                    </div>
                  </div>
                  <div class="faui-modal--icon-preview"></div>
                </div>
              </div>
            </div>
            <footer class="faui-modal--footer">
              <nav class="pagination pager" role="navigation" aria-labelledby="pagination-heading">
                <ul class="page-buttons pager__items js-pager__items ${!this.settings.clickInsert ? 'pager__items--insert' : ''}"></ul>
              </nav>
              ${this.settings.clickInsert ? '' : `<button class="faui-insert-icon-button button js-form-submit form-submit" disabled>${this.settings.messages.insert_label}</button>`}
            </footer>
          </div>
        </div>
      `);

      $('body').append(this.modalElement);
      this.sidebarTabs = this.modalElement.find('.faui-modal--sidebar-tabs');
      this.iconContainer = this.modalElement.find('.faui-modal--icon-preview');
      this.footerElement = this.modalElement.find('.pagination .page-info');
      this.searchInput = this.modalElement.find('.faui-modal--icon-search input');
      this.insertButton = this.modalElement.find('.faui-insert-icon-button');
      this.statsElement = this.modalElement.find('.faui-stats .icons-results-summary-count h1');
      this.currentPageElement = this.modalElement.find('.faui-stats .current-page');
      this.totalPagesElement = this.modalElement.find('.faui-stats .total-pages');
    }

    attachEventListeners() {
      this.modalElement.find('.faui-modal--header-close-btn i').on('click', this.closeModal.bind(this));
      this.searchInput.on('input', this.debounce(this.handleSearch.bind(this), 300));
      this.sidebarTabs.on('click', '.faui-modal--sidebar-tab-item', (event) => {
        const target = $(event.currentTarget);
        const libraryId = target.data('library-id');
        const libraryStyle = target.data('library-style');
        if (libraryStyle) {
          this.activeStyle = libraryStyle;
          this.sidebarTabs.find('.faui-modal--sidebar-tab-item[data-library-style]').removeClass('style-active');
          target.addClass('style-active');
        } else {
          this.activeCategory = libraryId;
          this.sidebarTabs.find('.faui-modal--sidebar-tab-item[data-library-id]').removeClass('category-active');
          target.addClass('category-active');
        }
        this.currentPage = 1;
        this.renderIcons();
        this.updateSidebarCounts();
      });

      this.iconContainer.on('click', '.faui-icon-item', (event) => {
        const target = $(event.currentTarget);
        this.iconContainer.find('.faui-icon-item').removeClass('icon-active');
        target.addClass('icon-active');
        const selectedIconClass = target.data('filter');
        this.settings.selectedIcon = selectedIconClass;

        if (this.settings.clickInsert) {
          this.insertIcon();
        } else {
          this.updateInsertButtonState();
          this.insertButton.off('click');
          this.insertButton.on('click', this.insertIcon.bind(this));
        }
      });

      this.modalElement.find('.faui-icon-families').on('click', '.icons-facet-tab', (event) => {
        const target = $(event.currentTarget);
        const family = target.data('family');
        const type = target.data('type');

        if (family) {
          this.activeFamily = this.activeFamily === family ? 'all' : family;
        }
        if (type) {
          this.activeType = this.activeType === type ? 'all' : type;
        }

        this.currentPage = 1;
        this.renderIcons();
        this.updateSidebarCounts();
      });

      document.addEventListener('DOMContentLoaded', function() {
        const scrollMain = document.querySelector('.faui-modal--icon-preview-wrap');
        const searchSticky = document.querySelector('.search-sticky');
        const searchBorder = document.querySelector('.search-sticky-shadow');

        scrollMain.addEventListener('scroll', function() {
          if (scrollMain.scrollTop >= 50) {
            searchSticky.classList.add('search-sticky--is-sticky');
            searchBorder.classList.remove('search-sticky--border');
          } else {
            searchSticky.classList.remove('search-sticky--is-sticky');
            searchBorder.classList.add('search-sticky--border');
          }
        });
      });
    }

    debounce(func, wait) {
      let timeout;
      return function(...args) {
        const context = this;
        if (timeout) clearTimeout(timeout);
        timeout = setTimeout(() => {
          timeout = null;
          func.apply(context, args);
        }, wait);
      };
    }

    openModal() {
      this.modalElement.show();
      this.setIconActive();
    }

    closeModal() {
      this.modalElement.hide();
    }

    handleSearch(event) {
      this.searchQuery = event.target.value.toLowerCase();
      this.currentPage = 1;
      this.renderIcons();
      this.updateSidebarCounts();
    }

    filterIcons() {
      let icons = this.filterIconsBySidebar();

      if (this.activeStyle !== 'all') {
        icons = icons.filter(icon => icon.style === this.activeStyle);
      }

      return icons;
    }

    renderSidebarTabs() {
      this.sidebarTabs.empty();

      const totalIcons = this.filterIcons().length;

      this.sidebarTabs.append(`<h3 class="h6-muted-text-uppercase">Style</h3><ul class="icons-facets-group-styles"></ul>`);
      this.sidebarTabsGroupStyle = this.modalElement.find('.icons-facets-group-styles');
      this.sidebarTabsGroupStyle.append(`
        <li class="faui-modal--sidebar-tab-item style-active" data-library-style="all">
          <span style="flex: 1 1 auto;"><i class="fa-solid fa-grid-2"></i>All styles</span>
          ${this.settings.showCount ? `<span class="icons-facet-count margin-left-sm">${totalIcons}</span>` : ''}
        </li>
      `);

      const styles = this.getAllStyles();

      styles.forEach(style => {
        const styleCount = this.filterIcons().filter(icon => icon.style === style).length;
        if (styleCount > 0 && style !== 'brands') {
          let style_name = '';
          let style_icon = '';
          switch (style) {
            case 'solid':
              style_name = style;
              style_icon = "circle";
              break;
            case 'regular':
              style_name = style;
              style_icon = this.versionType === 'pro' ? "circle-half-stroke" : "circle";
              break;
            case 'light':
              style_name = style;
              style_icon = "circle-half-stroke";
              break;
            case 'thin':
              style_name = style;
              style_icon = "circle-half-stroke";
              break;
            case 'duotone':
              style_name = style;
              style_icon = "circle-half";
              break;
          }
          this.sidebarTabsGroupStyle.append(`
            <li class="faui-modal--sidebar-tab-item" data-library-style="${style}">
              <span style="flex: 1 1 auto;"><i class="fa-${style} fa-${style_icon}"></i>${style.charAt(0).toUpperCase() + style.slice(1)}</span>
              ${this.settings.showCount ? `<span class="icons-facet-count margin-left-sm">${styleCount}</span>` : ''}
            </li>
          `);
        }
      });

      this.sidebarTabs.append(`<h3 class="h6-muted-text-uppercase">Categories</h3><div class="fa-ui--refinement-list list-scrollbar"><ul class="icons-facets-group-categories"></ul></div>`);
      this.sidebarTabsGroupCategories = this.modalElement.find('.icons-facets-group-categories');
      this.sidebarTabsGroupCategories.append(`
        <li class="faui-modal--sidebar-tab-item category-active" data-library-id="all_categories">
          <span class="icons-facet-affordance position-relative margin-right-sm"><i class="fas fa-layer-group fa-fw"></i></span>
          <span style="flex: 1 1 auto;">All Categories</span>
        </li>
      `);

      let categoryIcons = {
        'Accessibility' : 'fa-universal-access',
        'Alert' : 'fa-bell',
        'Alphabet' : 'fa-font',
        'Animals' : 'fa-paw',
        'Arrows' : 'fa-square-up-right',
        'Astronomy' : 'fa-meteor',
        'Automotive' : 'fa-car',
        'Buildings' : 'fa-building',
        'Business' : 'fa-briefcase',
        'Camping' : 'fa-campground',
        'Charity' : 'fa-hands-holding-child',
        'Charts + Diagrams' : 'fa-chart-line',
        'Childhood' : 'fa-ice-cream',
        'Clothing + Fashion' : 'fa-shirt',
        'Coding' : 'fa-code',
        'Communication' : 'fa-comment-dots',
        'Connectivity' : 'fa-signal',
        'Construction' : 'fa-person-digging',
        'Design' : 'fa-palette',
        'Devices + Hardware' : 'fa-computer',
        'Disaster + Crisis' : 'fa-burst',
        'Editing' : 'fa-pencil',
        'Education' : 'fa-graduation-cap',
        'Emoji' : 'fa-face-grin-wink',
        'Energy' : 'fa-bolt',
        'Files' : 'fa-file',
        'Film + Video' : 'fa-film',
        'Food + Beverage' : 'fa-burger',
        'Fruits + Vegetables' : 'fa-apple-whole',
        'Gaming' : 'fa-gamepad',
        'Genders' : 'fa-venus-mars',
        'Halloween' : 'fa-ghost',
        'Hands' : 'fa-hand',
        'Holidays' : 'fa-champagne-glasses',
        'Household' : 'fa-bath',
        'Humanitarian' : 'fa-parachute-box',
        'Logistics' : 'fa-truck-fast',
        'Maps' : 'fa-map',
        'Maritime' : 'fa-anchor',
        'Marketing' : 'fa-bullseye',
        'Mathematics' : 'fa-calculator',
        'Media Playback' : 'fa-forward',
        'Medical + Health' : 'fa-stethoscope',
        'Money' : 'fa-money-bill-wave',
        'Moving' : 'fa-dolly',
        'Music + Audio' : 'fa-music',
        'Nature' : 'fa-tree',
        'Numbers' : 'fa-9',
        'Photos + Images' : 'fa-image',
        'Political' : 'fa-check-double',
        'Punctuation + Symbols' : 'fa-quote-left',
        'Religion' : 'fa-person-praying',
        'Science' : 'fa-microscope',
        'Science Fiction' : 'fa-rocket',
        'Security' : 'fa-shield',
        'Shapes' : 'fa-shapes',
        'Shopping' : 'fa-basket-shopping',
        'Social' : 'fa-hashtag',
        'Spinners' : 'fa-arrows-rotate',
        'Sports + Fitness' : 'fa-heart-pulse',
        'Text Formatting' : 'fa-text-height',
        'Time' : 'fa-clock',
        'Toggle' : 'fa-toggle-on',
        'Transportation' : 'fa-truck-plane',
        'Travel + Hotel' : 'fa-plane-departure',
        'Users + People' : 'fa-children',
        'Weather' : 'fa-cloud-sun',
        'Writing' : 'fa-keyboard',
        'Sponsors' : 'fa-circle-dollar-to-slot',
        'Uncategorized' : 'fa-circle-question',
      };

      Object.keys(this.source).forEach(category => {
        if (category !== 'Brands') {
          const categoryCount = this.filterIcons().filter(icon => {
            return Object.keys(this.source[category]).includes(icon.name) && (this.activeFamily === 'all' || icon.family === this.activeFamily) && (this.activeType === 'all' || icon.type === this.activeType);
          }).length;

          const iconClass = categoryIcons[category] || 'fa-wand-magic-sparkles';
          this.sidebarTabsGroupCategories.append(`
            <li class="faui-modal--sidebar-tab-item" data-library-id="${category}">
              <span class="icons-facet-affordance position-relative margin-right-sm"><i class="fas ${iconClass} fa-fw"></i></span>
              <span style="flex: 1 1 auto;">${category}</span>
              ${this.settings.showCount ? `<span class="icons-facet-count margin-left-sm">${categoryCount}</span>` : ''}
            </li>
          `);
        }
      });

      if (!this.settings.showCount) {
        this.updateSidebarCounts();
      }
    }

    getAllStyles() {
      const styles = new Set();
      Object.values(this.source).forEach(category => {
        Object.values(category).forEach(iconData => {
          iconData.icons.forEach(icon => {
            styles.add(icon.style);
          });
        });
      });
      return Array.from(styles);
    }

    renderIcons() {
      const icons = this.filterIcons();
      this.iconContainer.empty();

      if (this.allowEmpty && this.currentPage === 1) {
        this.iconContainer.append(`
          <div class="faui-icon-item" data-library-id="fa-regular" data-filter="" data-library-name="fontAwesome" data-font-style="">
            <div class="faui-icon-item-inner">
              <i class="fa-regular fa- faui-icon-none">&nbsp;</i>
              <div class="faui-icon-item-name" title="None">None</div>
            </div>
          </div>
        `);
      }

      const start = (this.currentPage - 1) * this.iconsPerPage;
      const end = start + this.iconsPerPage;
      const iconsToShow = icons.slice(start, end);

      // Create a Map from styleAliases for faster and more efficient access
      const styleAliases = new Map([
        ['fa-solid', 'fas'],
        ['fa-regular', 'far'],
        ['fa-light', 'fal'],
        ['fa-thin', 'fat'],
        ['fa-duotone', 'fad'],
        ['fa-sharp fa-solid', 'fass'],
        ['fa-sharp fa-regular', 'fasr'],
        ['fa-sharp fa-light', 'fasl'],
        ['fa-sharp fa-thin', 'fast'],
        ['fa-sharp fa-duotone', 'fasd'],
        ['fa-brands', 'fab']
      ]);

      iconsToShow.forEach(icon => {
        console.log(icon.class);

        // Split the icon classes into an array of classes
        const classes = icon.class.split(' ');

        // Replace classes using the Map
        const newClasses = classes.map(cls => styleAliases.get(cls) || cls).join(' ');

        // Extract icon name
        const iconName = icon.name.replace(/^fa-/, '');

        // Append the new icon element to the container
        this.iconContainer.append(`
          <div class="faui-icon-item" data-library-id="${icon.style}" data-filter="${newClasses}" data-library-name="fontAwesome" data-font-style="${icon.style}">
            <div class="faui-icon-item-inner">
              <i class="${newClasses}"></i>
              <div class="faui-icon-item-name" title="${iconName}">${iconName}</div>
            </div>
          </div>
        `);
      });

      this.totalPages = Math.ceil(icons.length / this.iconsPerPage);
      this.updatePagination();
      this.updateInsertButtonState();
      this.updateStats(icons.length);
    }

    updateSelectedIcon() {
      this.$iconSelector.find('.selected-icon').remove();
      this.$iconSelector.find('.selector').prepend(`
        <span class="selected-icon"><i class="${this.settings.selectedIcon}"></i></span>
      `);
      this.$input.val(this.settings.selectedIcon).trigger('change');
    }

    setIconActive() {
      if (this.settings.selectedIcon) {
        this.iconContainer.find('.faui-icon-item').each((index, item) => {
          const $item = $(item);
          const iconClass = $item.data('filter');
          if (iconClass === this.settings.selectedIcon) {
            $item.addClass('icon-active');
          }
        });
      }
      this.updateInsertButtonState();
    }

    updateInsertButtonState() {
      if (this.iconContainer.find('.faui-icon-item.icon-active').length > 0) {
        this.insertButton.prop('disabled', false);
      } else {
        this.insertButton.prop('disabled', true);
      }
    }

    insertIcon() {
      const activeIcon = this.iconContainer.find('.faui-icon-item.icon-active');
      const iconClass = activeIcon.data('filter');
      this.settings.selectedIcon = iconClass;
      this.updateSelectedIcon();
      this.closeModal();
    }

    checkForProIcons() {
      for (const category in this.source) {
        for (const iconName in this.source[category]) {
          const iconData = this.source[category][iconName];
          if (iconData.icons.some(icon => icon.type === 'pro')) {
            return true;
          }
        }
      }
      return false;
    }

    checkForSharpIcons() {
      for (const category in this.source) {
        for (const iconName in this.source[category]) {
          const iconData = this.source[category][iconName];
          if (iconData.icons.some(icon => icon.family === 'sharp')) {
            return true;
          }
        }
      }
      return false;
    }

    toggleElementsVisibility() {
      if (!this.hasProIcons) {
        this.modalElement.find('.ais-ToggleRefinement').hide();
      }
      if (!this.hasSharpIcons) {
        this.modalElement.find('.icons-facets-group-families button[data-family="sharp"]').hide();
      }
    }

    prevPage(event) {
      event.preventDefault();
      if (this.currentPage > 1) {
        this.currentPage--;
        this.renderIcons();
      }
    }

    nextPage(event) {
      event.preventDefault();
      if (this.currentPage < this.totalPages) {
        this.currentPage++;
        this.renderIcons();
      }
    }

    updatePagination() {
      const paginationContainer = this.modalElement.find('.pagination .page-buttons');
      paginationContainer.empty();

      const pagesToShow = 6;
      const halfPagesToShow = Math.floor(pagesToShow / 2);

      let startPage = Math.max(1, this.currentPage - halfPagesToShow);
      let endPage = Math.min(this.totalPages, this.currentPage + halfPagesToShow);

      if (this.currentPage <= halfPagesToShow) {
        endPage = Math.min(this.totalPages, pagesToShow);
      }

      if (this.currentPage + halfPagesToShow >= this.totalPages) {
        startPage = Math.max(1, this.totalPages - pagesToShow + 1);
      }

      paginationContainer.append(`<li class="pager__item pager__item--action pager__item--previous"><a href="#" title="Go to previous page" rel="prev" aria-label="Previous Page" class="prev-page pager__link pager__link--action-link" style="display: none">Prev</a></li>`);
      if (startPage > 1) {
        paginationContainer.append(`<li class="pager__item pager__item--number"><a href="#" class="number-page pager__link">1</a></li>`);
        if (startPage > 2) {
          paginationContainer.append(`<li class="pager__item pager__item--ellipsis" role="presentation">…</li>`);
        }
      }

      for (let i = startPage; i <= endPage; i++) {
        paginationContainer.append(`<li class="pager__item ${i === this.currentPage ? 'pager__item--active' : ''}pager__item--number"><a href="#" class="number-page pager__link ${i === this.currentPage ? 'is-active' : ''}">${i}</a></li>`);
      }

      if (endPage < this.totalPages) {
        if (endPage < this.totalPages - 1) {
          paginationContainer.append(`<li class="pager__item pager__item--ellipsis" role="presentation">…</li>`);
        }
        paginationContainer.append(`<li class="pager__item pager__item--number"><a href="#" class="number-page pager__link">${this.totalPages}</a></li>`);
      }
      paginationContainer.append(`<li class="pager__item pager__item--action pager__item--next"><a href="#" title="Go to next page" rel="next" aria-label="Next Page" class="next-page pager__link pager__link--action-link" style="display: none">Next</a></li>`);

      this.modalElement.find('.pagination .page-buttons a.number-page').on('click', (event) => {
        event.preventDefault();
        this.currentPage = parseInt($(event.currentTarget).text());
        this.renderIcons();
      });

      this.modalElement.find('.pagination .prev-page').on('click', this.prevPage.bind(this));
      this.modalElement.find('.pagination .next-page').on('click', this.nextPage.bind(this));

      this.modalElement.find('.pagination .prev-page').toggle(this.currentPage !== 1);
      this.modalElement.find('.pagination .next-page').toggle(this.currentPage !== this.totalPages);
    }

    updateStats(totalIcons) {
      this.statsElement.text(`${totalIcons} Icons`);
      this.currentPageElement.text(this.currentPage);
      this.totalPagesElement.text(this.totalPages);
    }

    updateSidebarCounts() {
      const totalIcons = this.filterIcons().length;
      this.sidebarTabs.find('[data-library-style="all"] .icons-facet-count').text(totalIcons).show();

      const styles = this.getAllStyles();
      styles.forEach(style => {
        const styleCount = this.filterIconsBySidebar().filter(icon => icon.style === style).length;
        // Hide elements with count 0
        if (styleCount === 0) {
          this.sidebarTabs.find(`[data-library-style="${style}"]`).hide();
        } else {
          this.sidebarTabs.find(`[data-library-style="${style}"]`).show();
          if (this.settings.showCount) {
            this.sidebarTabs.find(`[data-library-style="${style}"] .icons-facet-count`).text(styleCount);
          }
        }
      });

      Object.keys(this.source).forEach(category => {
        if (category !== 'Brands') {
          const categoryCount = this.filterIcons().filter(icon => {
            return Object.keys(this.source[category]).includes(icon.name) && (this.activeFamily === 'all' || icon.family === this.activeFamily) && (this.activeType === 'all' || icon.type === this.activeType);
          }).length;
          // Hide elements with count 0
          if (categoryCount === 0) {
            this.sidebarTabs.find(`[data-library-id="${category}"]`).hide();
          } else {
            this.sidebarTabs.find(`[data-library-id="${category}"]`).show();
            if (this.settings.showCount) {
              this.sidebarTabs.find(`[data-library-id="${category}"] .icons-facet-count`).text(categoryCount);
            }
          }
        }
      });
    }

    filterIconsBySidebar() {
      const uniqueIcons = new Map();
      Object.keys(this.source).forEach(category => {
        const categoryIcons = this.source[category];
        Object.keys(categoryIcons).forEach(iconName => {
          const iconData = categoryIcons[iconName];
          iconData.icons.forEach(icon => {
            const iconKey = `${iconName}-${icon.style}-${icon.family}`;
            if (!uniqueIcons.has(iconKey)) {
              uniqueIcons.set(iconKey, {
                ...icon,
                name: iconName,
                label: iconData.label,
                search_terms: iconData.search_terms,
                free: iconData.free
              });
            }
          });
        });
      });

      let icons = Array.from(uniqueIcons.values());

      if (this.searchQuery) {
        icons = icons.filter(icon => icon.search_terms.includes(this.searchQuery));
      }

      if (this.activeFamily !== 'all') {
        if (this.activeFamily === 'brands') {
          icons = icons.filter(icon => icon.style === 'brands');
        }
        else {
          icons = icons.filter(icon => icon.family === this.activeFamily);
        }
      }

      if (this.activeType !== 'all') {
        icons = icons.filter(icon => icon.type === this.activeType);
        if (this.activeType == 'free') {
          let brand_icons = icons.filter(icon => icon.style === 'brands');
          icons = icons.filter(icon => icon.family === 'classic');
          icons = icons.filter(icon => icon.free.includes(icon.style));
          icons = [...icons, ...brand_icons];
        }
      }

      if (this.activeCategory !== 'all_categories') {
        icons = icons.filter(icon => {
          for (const category in this.source) {
            if (category === this.activeCategory && this.source[category][icon.name]) {
              return true;
            }
          }
          return false;
        });
      }

      return icons;
    }
  }
})(jQuery);
